==> checkbox_0.7.2.tar.gz: checkbox-0.7.2/plugins/intro_prompt.py <==
#
# This file is part of Checkbox.
#
# Copyright 2008 Canonical Ltd.
#
# Checkbox is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Checkbox is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
#
from gettext import gettext as _

from checkbox.plugin import Plugin


class IntroPrompt(Plugin):

    def register(self, manager):
        super(IntroPrompt, self).register(manager)
        # Introduction should be prompted last
        self._manager.reactor.call_on("prompt-begin", self.prompt_begin, 100)

    def prompt_begin(self, interface):
        interface.show_intro(_("Welcome to System Testing!"),
            _("""\
This application will gather information from your system. Then, \
you will be asked manual tests to confirm that the system is working \
properly. Finally, you will be asked for the e-mail address you use \
to sign in to Launchpad in order to submit the information and your \
results.

If you do not have a Launchpad account, please register here:

  https://launchpad.net/+login

Thank you for taking the time to test your system."""))


factory = IntroPrompt

==> checkbox_0.9.1.tar.gz: checkbox-0.9.1/plugins/intro_prompt.py <==
#
# This file is part of Checkbox.
#
# Copyright 2008 Canonical Ltd.
#
# Checkbox is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Checkbox is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
#
from gettext import gettext as _

from checkbox.plugin import Plugin
from checkbox.user_interface import PREV


class IntroPrompt(Plugin):

    def register(self, manager):
        super(IntroPrompt, self).register(manager)

        self._recover = False

        self._manager.reactor.call_on("begin-recover", self.begin_recover)

        # Introduction should be prompted last
        self._manager.reactor.call_on("prompt-begin", self.prompt_begin, 100)

    def begin_recover(self):
        self._recover = True

    def prompt_begin(self, interface):
        if interface.direction == PREV or not self._recover:
            self._recover = False
            interface.show_text(_("""\
Welcome to System Testing!

Checkbox provides tests to confirm that your system is working \
properly. Once you are finished running the tests, you can view \
a summary report for your system."""),
                previous="")


factory = IntroPrompt
